@@ -55,129 +55,34 @@ class CGContentUtils extends CGExtensions
   var $_template_cache;
   var $_default_template;
 
-  /*---------------------------------------------------------
-   __construct()
-   ---------------------------------------------------------*/
   public function __construct()
   {
     parent::__construct();
 
     global $CMS_ADMIN_PAGE;
-    if( $CMS_ADMIN_PAGE && (version_compare(CMS_VERSION,'1.7') >= 0) )
-      {
-	$this->RegisterBulkContentFunction($this->Lang('advanced_copy'),'admin_copycontent');
-      }
+    if( $CMS_ADMIN_PAGE ) {
+      $this->RegisterBulkContentFunction($this->Lang('advanced_copy'),'admin_copycontent');
+    }
   }
 
-  /*---------------------------------------------------------
-   GetName()
-   ---------------------------------------------------------*/
-  function GetName()
-  {
-    return 'CGContentUtils';
-  }
+  function GetName() { return 'CGContentUtils'; }
+  function GetFriendlyName() { return $this->Lang('friendlyname'); }
+  function GetVersion() { return '1.3.6'; }
+  function GetHelp() { return file_get_contents(dirname(__FILE__).'/help.inc'); }
+  function GetAuthor() { return 'calguy1000'; }
+  function GetAuthorEmail() { return 'calguy1000@cmsmadesimple.org'; }
+  function GetChangeLog() { return file_get_contents(dirname(__FILE__).'/changelog.inc'); }
+  function IsPluginModule() { return false; }
+  function HasAdmin() { return true; }
+  function IsAdminOnly() { return true; }
+  function GetAdminSection() { return 'extensions'; }
+  function GetAdminDescription() { return $this->Lang('moddescription'); }
+  function GetDependencies() { return array('CGExtensions'=>'1.37.2', 'JQueryTools'=>'1.2.5'); }
+  function MinimumCMSVersion() { return '1.11.7'; }
+  function InstallPostMessage() { return $this->Lang('postinstall'); }
+  function UninstallPostMessage() { return $this->Lang('postuninstall'); }
+  function UninstallPreMessage() { return $this->Lang('ask_really_uninstall'); }	
 
-  /*---------------------------------------------------------
-   GetFriendlyName()
-   ---------------------------------------------------------*/
-  function GetFriendlyName()
-  {
-    return $this->Lang('friendlyname');
-  }
-
-	
-  /*---------------------------------------------------------
-   GetVersion()
-   ---------------------------------------------------------*/
-  function GetVersion()
-  {
-    return '1.3.2';
-  }
-
-
-  /*---------------------------------------------------------
-   GetHelp()
-   ---------------------------------------------------------*/
-  function GetHelp()
-  {
-    return file_get_contents(dirname(__FILE__).'/help.inc');
-  }
-
-
-  /*---------------------------------------------------------
-   GetAuthor()
-   ---------------------------------------------------------*/
-  function GetAuthor()
-  {
-    return 'calguy1000';
-  }
-
-
-  /*---------------------------------------------------------
-   GetAuthorEmail()
-   ---------------------------------------------------------*/
-  function GetAuthorEmail()
-  {
-    return 'calguy1000@cmsmadesimple.org';
-  }
-
-
-  /*---------------------------------------------------------
-   GetChangeLog()
-   ---------------------------------------------------------*/
-  function GetChangeLog()
-  {
-    return file_get_contents(dirname(__FILE__).'/changelog.inc');
-  }
-  
-  /*---------------------------------------------------------
-   IsPluginModule()
-   ---------------------------------------------------------*/
-  function IsPluginModule()
-  {
-    return false;
-  }
-
-
-  /*---------------------------------------------------------
-   HasAdmin()
-   ---------------------------------------------------------*/
-  function HasAdmin()
-  {
-    return true;
-  }
-
-
-  /*---------------------------------------------------------
-   IsAdminOnly()
-   ---------------------------------------------------------*/
-  function IsAdminOnly()
-  {
-    return true;
-  }
-
-
-  /*---------------------------------------------------------
-   GetAdminSection()
-   ---------------------------------------------------------*/
-  function GetAdminSection()
-  {
-    return 'extensions';
-  }
-
-
-  /*---------------------------------------------------------
-   GetAdminDescription()
-   ---------------------------------------------------------*/
-  function GetAdminDescription()
-  {
-    return $this->Lang('moddescription');
-  }
-
-
-  /*---------------------------------------------------------
-   VisibleToAdminUser()
-   ---------------------------------------------------------*/
   function VisibleToAdminUser()
   {
     return( $this->CheckPermission('Modify Any Page') ||
@@ -187,26 +92,11 @@ class CGContentUtils extends CGExtensions
 	    $this->CheckPermission('Modify Global Content Blocks') );
   }
 
-
-  /*---------------------------------------------------------
-   GetDependencies()
-   ---------------------------------------------------------*/
-  function GetDependencies()
-  {
-    return array('CGExtensions'=>'1.29',
-		 'JQueryTools'=>'1.0.3');
-  }
-
-
-  /*---------------------------------------------------------
-   GetHeaderHTML()
-   ---------------------------------------------------------*/
   function GetHeaderHTML()
   {
     $txt = '';
     $obj = $this->GetModuleInstance('JQueryTools');
-    if( is_object($obj) )
-      {
+    if( is_object($obj) ) {
 $tmpl = <<<EOT
 {JQueryTools action='incjs' exclude='form'}
 {JQueryTools action='ready'}
@@ -217,65 +107,19 @@ EOT;
   }	
 
 
-  /*---------------------------------------------------------
-   MinimumCMSVersion()
-   ---------------------------------------------------------*/
-  function MinimumCMSVersion()
-  {
-    return "1.10.2";
-  }
-	
-	
-  /*---------------------------------------------------------
-   SetParameters()
-   ---------------------------------------------------------*/
-  function SetParameters()
-  {
-	// nothing here
-  }
-
-
-  /*---------------------------------------------------------
-   InstallPostMessage()
-   ---------------------------------------------------------*/
-  function InstallPostMessage()
-  {
-    return $this->Lang('postinstall');
-  }
-
-
-  /*---------------------------------------------------------
-   UninstallPostMessage()
-   ---------------------------------------------------------*/
-  function UninstallPostMessage()
-  {
-    return $this->Lang('postuninstall');
-  }
-
-
-  /*---------------------------------------------------------
-   UninstallPreMessage()
-   ---------------------------------------------------------*/
-  function UninstallPreMessage()
-  {
-    return $this->Lang('ask_really_uninstall');
-  }	
-
-
   /*---------------------------------------------------------
    SuppressAdminOutput()
    ---------------------------------------------------------*/
   function SuppressAdminOutput(&$request)
   {
-    if( isset($_REQUEST['mact']) )
-      {
-	$ary = explode(',', cms_htmlentities($_REQUEST['mact']), 4);
-	$module = (isset($ary[0])?$ary[0]:'');
-	$id = (isset($ary[1])?$ary[1]:'');
-	$action = (isset($ary[2])?$ary[2]:'');
-
-	if( $action == 'do_export' ) return TRUE;
-      }
+    if( isset($_REQUEST['mact']) ) {
+      $ary = explode(',', cms_htmlentities($_REQUEST['mact']), 4);
+      $module = (isset($ary[0])?$ary[0]:'');
+      $id = (isset($ary[1])?$ary[1]:'');
+      $action = (isset($ary[2])?$ary[2]:'');
+      
+      if( $action == 'do_export' ) return TRUE;
+    }
 
     return FALSE;
   }
@@ -292,28 +136,22 @@ EOT;
     $this->_dom = new DOMDocument("1.0","UTF8");
     $root = $this->_dom->createElement('cms_export');
 
-    if( $start_id == -1 )
-      {
-	$children = TRUE;
-	$allchildren = $hm->getChildren(TRUE);
-	foreach( $allchildren as $child )
-	  {
-	    $domnode = $this->_exportContentObj($child,$children);
-	    if( $domnode )
-	      {
-		$root->appendChild($domnode);
-	      }
-	  }
+    if( $start_id == -1 ) {
+      $children = TRUE;
+      $allchildren = $hm->getChildren(TRUE,TRUE);
+      foreach( $allchildren as $child ) {
+	if( !$child ) continue;
+	$domnode = $this->_exportContentObj($child,$children);
+	if( $domnode ) $root->appendChild($domnode);
       }
-    else
-      {
-	$node = $hm->sureGetNodeByID($start_id);
+    }
+    else {
+      $node = $hm->sureGetNodeByID($start_id);
+      if( !is_null($node) ) {
 	$parent_domnode = $this->_exportContentObj($node,$children);
-	if( $parent_domnode )
-	  {
-	    $root->appendChild($parent_domnode);
-	  }
+	if( $parent_domnode ) $root->appendChild($parent_domnode);
       }
+    }
     $this->_dom->appendChild($root);
     return $this->_dom->saveXML();
   }
@@ -324,19 +162,17 @@ EOT;
    ---------------------------------------------------------*/
   function _exportContentObj(&$node,$children)
   {
-    $content_obj = $node->getContent(false,true,false);
+    $content_obj = $node->getContent(FALSE,TRUE,TRUE);
     if( !is_object($content_obj) ) return;
     $domnode = $this->_createDomContentObj($content_obj);
 
-    if( $node->hasChildren() && $children )
-      {
-	$tmp = $node->getChildren();
-	foreach( $tmp as $child )
-	  {
-	    $child_domnode = $this->_exportContentObj($child,$children);
-	    $domnode->appendChild($child_domnode);
-	  }
+    if( $node->hasChildren() && $children ) {
+      $tmp = $node->getChildren();
+      foreach( $tmp as $child ) {
+	$child_domnode = $this->_exportContentObj($child,$children);
+	if( $child_domnode ) $domnode->appendChild($child_domnode);
       }
+    }
 
     return $domnode;
   }
@@ -347,12 +183,11 @@ EOT;
    ---------------------------------------------------------*/
   function _getDefaultTemplateId()
   {
-    if( !$this->_default_template )
-      {
-	$gCms = cmsms();
-	$templateops = $gCms->GetTemplateOperations();
-	$this->_default_template = $templateops->LoadDefaultTemplate();
-      }
+    if( !$this->_default_template ) {
+      $gCms = cmsms();
+      $templateops = $gCms->GetTemplateOperations();
+      $this->_default_template = $templateops->LoadDefaultTemplate();
+    }
     return $this->_default_template->id;
   }
 
@@ -362,19 +197,15 @@ EOT;
    ---------------------------------------------------------*/
   function _getTemplateNameFromId($tplid)
   {
-    if( !$this->_template_cache )
-      {
-	$gCms = cmsms();
-	$db = $gCms->GetDb();
-	$query = 'SELECT template_id,template_name FROM '.cms_db_prefix().'templates ';
-	$tmp = $db->GetArray($query);
-	$this->_template_cache = cge_array::to_hash($tmp,'template_id');
-      }
+    if( !$this->_template_cache ) {
+      $gCms = cmsms();
+      $db = $gCms->GetDb();
+      $query = 'SELECT template_id,template_name FROM '.cms_db_prefix().'templates ';
+      $tmp = $db->GetArray($query);
+      $this->_template_cache = cge_array::to_hash($tmp,'template_id');
+    }
 
-    if( isset($this->_template_cache[$tplid]) )
-      {
-	return $this->_template_cache[$tplid]['template_name'];
-      }
+    if( isset($this->_template_cache[$tplid]) ) return $this->_template_cache[$tplid]['template_name'];
     return NULL;
   }
 
@@ -387,10 +218,9 @@ EOT;
     // force cache to load.
     $this->_getTemplateNameFromId(-1);
     
-    foreach( $this->_template_cache as $id => $rec )
-      {
-	if( $rec['template_name'] == $name ) return $id;
-      }
+    foreach( $this->_template_cache as $id => $rec ) {
+      if( $rec['template_name'] == $name ) return $id;
+    }
 
     return NULL;
   }
@@ -410,8 +240,7 @@ EOT;
     $sub = $this->_dom->createElement('alias',$content_obj->Alias());
     $root->appendChild($sub);
 
-    $sub = $this->_dom->createElement('template',
-				      $this->_getTemplateNameFromId($content_obj->TemplateID()));
+    $sub = $this->_dom->createElement('template',$this->_getTemplateNameFromId($content_obj->TemplateID()));
     $root->appendChild($sub);
 
     $cdata = $this->_dom->createCDATAsection($content_obj->MetaData());
@@ -457,13 +286,11 @@ EOT;
   function _get_childnode_value(&$parent,$nodename)
   {
     $children = $parent->childNodes;
-    foreach( $children as $childnode )
-      {
-	if( $childnode->nodeName == $nodename )
-	  {
-	    return $childnode->nodeValue;
-	  }
+    foreach( $children as $childnode ) {
+      if( $childnode->nodeName == $nodename ) {
+	return $childnode->nodeValue;
       }
+    }
     return NULL;
   }
 
@@ -471,13 +298,11 @@ EOT;
   function _get_childnode(&$parent,$nodename)
   {
     $children = $parent->childNodes;
-    foreach( $children as $childnode )
-      {
-	if( $childnode->nodeName == $nodename )
-	  {
-	    return $childnode;
-	  }
+    foreach( $children as $childnode ) {
+      if( $childnode->nodeName == $nodename ) {
+	return $childnode;
       }
+    }
     return NULL;
   }
 
@@ -495,20 +320,18 @@ EOT;
    ---------------------------------------------------------*/
   function _scanContent(&$node,$parent_id = 0)
   {
-    while( $node != NULL )
-      {
-	if( $node->nodeName != 'cms_content' ) break;
+    while( $node != NULL ) {
+      if( $node->nodeName != 'cms_content' ) break;
       
-	$content_obj = $this->_extractDomContentObj($node);
-	if( $content_obj )
-	  {
-	    //see if there are more.
-	    scan_content($node->firstChild,$parent_id++);
-	  }
-      
-	// go to the next
-	$node = $node->nextSibling;
+      $content_obj = $this->_extractDomContentObj($node);
+      if( $content_obj ) {
+	//see if there are more.
+	scan_content($node->firstChild,$parent_id++);
       }
+      
+      // go to the next
+      $node = $node->nextSibling;
+    }
   }
 
 
@@ -517,26 +340,23 @@ EOT;
    ---------------------------------------------------------*/
   function _importContent(&$node,$parent_id)
   {
-    while( $node != NULL )
-      {
-	if( $node->nodeName == 'cms_content' )
-	  {
-	    $content_obj = $this->_extractDomContentObj($node);
-	    if( $content_obj )
-	      {
-		//save it
-		$content_obj->SetParentId($parent_id);
-		$content_obj->SetOwner(get_userid());
-		$content_obj->Save();
-		$new_parent_id = $content_obj->Id();
-		//see if there are more.
-		$this->_importContent($node->firstChild,$new_parent_id);
-	      }
-	  }
-      
-	// go to the next
-	$node = $node->nextSibling;
+    while( $node != NULL ) {
+      if( $node->nodeName == 'cms_content' ) {
+	$content_obj = $this->_extractDomContentObj($node);
+	if( $content_obj ) {
+	  //save it
+	  $content_obj->SetParentId($parent_id);
+	  $content_obj->SetOwner(get_userid());
+	  $content_obj->Save();
+	  $new_parent_id = $content_obj->Id();
+	  //see if there are more.
+	  $this->_importContent($node->firstChild,$new_parent_id);
+	}
       }
+      
+      // go to the next
+      $node = $node->nextSibling;
+    }
   }
 
 
@@ -544,7 +364,7 @@ EOT;
    _extractDomContentObj()
    ---------------------------------------------------------*/
   function &_extractDomContentObj(&$node)
-    {
+  {
       /////////////////////////////////////////////////////////////////
       $gCms = cmsms();
       $contentops = $gCms->getContentOperations();
@@ -567,31 +387,26 @@ EOT;
 
       $alias = $this->_get_childnode_value($node,'alias');
       $tmp = $contentops->CheckAliasError($alias);
-      if( $tmp )
-	{
-	  $alias = '';
-	}
+      if( $tmp ) $alias = '';
       $content_obj->SetAlias($alias);
       
       // todo, handle null.
       $tpl_id = $this->_getTemplateIdFromName($this->_get_childnode_value($node,'template'));
-      if( !$tpl_id )
-	{
-	  $tpl_id = $this->_getDefaultTemplateId();
-	}
+      if( !$tpl_id ) {
+	$tpl_id = $this->_getDefaultTemplateId();
+      }
       $content_obj->SetTemplateId($tpl_id);
   
       // now to get the properties.
       $children = $node->childNodes;
-      foreach( $children as $childnode )
-	{
-	  if( $childnode->nodeName != 'property' ) continue;
-	  $propname = $this->_get_node_attribute($childnode,'name');
-	  $proptype = $this->_get_node_attribute($childnode,'type');
-	  $propval  = $childnode->nodeValue;
+      foreach( $children as $childnode ) {
+	if( $childnode->nodeName != 'property' ) continue;
+	$propname = $this->_get_node_attribute($childnode,'name');
+	$proptype = $this->_get_node_attribute($childnode,'type');
+	$propval  = $childnode->nodeValue;
       
-	  $content_obj->setPropertyValue($propname,$propval);
-	}
+	$content_obj->setPropertyValue($propname,$propval);
+      }
 
       return $content_obj;
     }
@@ -599,15 +414,14 @@ EOT;
 
   function HasCapability($capability,$params = array())
   {
-    switch( $capability )
-      {
-      case 'contentblocks':
-	return TRUE;
-      case 'bulkcontentoption':
-	return TRUE;
-      default:
-	return FALSE;
-      }
+    switch( $capability ) {
+    case 'contentblocks':
+      return TRUE;
+    case 'bulkcontentoption':
+      return TRUE;
+    default:
+      return FALSE;
+    }
   }
 	
 		
@@ -618,69 +432,61 @@ EOT;
     $config = $gCms->GetConfig();
 
     if( empty($blockName) ) return FALSE;
-    if( !isset($params['name']) ) return FALSE;
-    $name = trim($params['name']);
+    $name = $blockName;
+    if( isset($params['name']) ) $name = trim($params['name']);
 
-    if( isset($params['groups']) && !$this->CheckPermission('Manage All Content')) // manage all content is just that... manage everything.
+    if( isset($params['groups']) && !$this->CheckPermission('Manage All Content')) { 
+      // manage all content is just that... manage everything.
+      // groups are specified, and we don't get superuser privilege.
+      $my_uid = get_userid(FALSE); 
+      if( $my_uid <= 0 ) return FALSE; // not loggedin?
+
+      $allgroups = array();
       {
-	// groups are specified, and we don't get superuser privilege.
-	$my_uid = get_userid(FALSE); 
-	if( $my_uid <= 0 ) return FALSE; // not loggedin?
-
-	$allgroups = array();
-	{
-	  // get a hash of all of the groups and ids.
-	  $tmp = cmsms()->GetGroupOperations()->LoadGroups();
-	  if( !is_array($tmp) || count($tmp) == 0 ) return FALSE; // no groups?
-	  foreach( $tmp as $one )
-	    {
-	      if( !$one->active ) continue;
-	      $allgroups[$one->name] = $one->id;
-	    }
+	// get a hash of all of the groups and ids.
+	$tmp = cmsms()->GetGroupOperations()->LoadGroups();
+	if( !is_array($tmp) || count($tmp) == 0 ) return FALSE; // no groups?
+	foreach( $tmp as $one ) {
+	  if( !$one->active ) continue;
+	  $allgroups[$one->name] = $one->id;
 	}
-
-	// get the gids of all of the groups that this field is visible to.
-	$groups = array();
-	$tmp = explode(',',$params['groups']);
-	foreach( $tmp as $one )
-	  {
-	    $one = trim($one);
-	    if( $one )
-	      {
-		if( !isset($allgroups[$one]) ) continue;
-		$groups[] = $allgroups[$one];
-	      }
-	  }
-
-	if( count($groups) == 0 ) 
-	  {
-	    // no valid groups specified... user has to be an administrator
-	    $groups[] = 1;
-	  }
-
-	// now do the check to see if the current user is a member of the specified group(s)
-	$groups = array_unique($groups);
-	$valid = FALSE;
-	foreach( $groups as $gid )
-	  {
-	    $users = cmsms()->GetUserOperations()->LoadUsersInGroup($gid);
-	    if( !is_array($users) || !count($users) ) continue;
-	    foreach( $users as $user )
-	      {
-		if( $user->id == $my_uid )
-		  {
-		    $valid = TRUE;
-		    break;
-		  }
-	      }
-	    if( $valid ) break;
-	  }
-	if( !$valid )
-	  {
-	    // user is not a member of any of the specified groups
-	    return FALSE;
-	  }
       }
+      
+      // get the gids of all of the groups that this field is visible to.
+      $groups = array();
+      $tmp = explode(',',$params['groups']);
+      foreach( $tmp as $one ) {
+	$one = trim($one);
+	if( $one ) {
+	  if( !isset($allgroups[$one]) ) continue;
+	  $groups[] = $allgroups[$one];
+	}
+      }
+      
+      if( count($groups) == 0 ) {
+	// no valid groups specified... user has to be an administrator
+	$groups[] = 1;
+      }
+
+      // now do the check to see if the current user is a member of the specified group(s)
+      $groups = array_unique($groups);
+      $valid = FALSE;
+      foreach( $groups as $gid ) {
+	$users = cmsms()->GetUserOperations()->LoadUsersInGroup($gid);
+	if( !is_array($users) || !count($users) ) continue;
+	foreach( $users as $user ) {
+	  if( $user->id == $my_uid ) {
+	    $valid = TRUE;
+	    break;
+	  }
+	}
+	if( $valid ) break;
+      }
+      if( !$valid ) {
+	// user is not a member of any of the specified groups
+	return FALSE;
+      }
+    }
 
     $query = 'SELECT * FROM '.cms_db_prefix().'module_cgcontentutils WHERE name = ?';
     $row = $db->GetRow($query,array($name));
@@ -688,130 +494,116 @@ EOT;
     $row['attribs'] = unserialize($row['attribs']);
 
     $txt = '';
-    switch( $row['type'] )
+    switch( $row['type'] ) {
+    case 'textinput':
+      $tmp = '<input type="text" name="%s" size="%d" maxlength="%d" value="%s"/>';
+      $txt = sprintf($tmp,$blockName,$row['attribs']['length'],$row['attribs']['maxlength'],
+		     ($adding)?$row['value']:$value);
+      break;
+      
+    case 'textarea':
+      $tmp = '<textarea name="%s" rows="%d" cols="%d">%s</textarea>';
+      $txt = sprintf($tmp,$blockName,$row['attribs']['rows'],$row['attribs']['cols'],
+		     ($adding)?$row['value']:$value);
+      break;
+      
+    case 'pageselector':
+      $contentops = $gCms->GetContentOperations();
+      if( $value == '' ) $value = $row['value'];
+      $txt = $contentops->CreateHierarchyDropdown('',$value,$blockName,1,1);
+      break;
+
+    case 'dropdown':
       {
-      case 'textinput':
-	$tmp = '<input type="text" name="%s" size="%d" maxlength="%d" value="%s"/>';
-	$txt = sprintf($tmp,$blockName,$row['attribs']['length'],$row['attribs']['maxlength'],
-		       ($adding)?$row['value']:$value);
-	break;
-
-      case 'textarea':
-	$tmp = '<textarea name="%s" rows="%d" cols="%d">%s</textarea>';
-	$txt = sprintf($tmp,$blockName,$row['attribs']['rows'],$row['attribs']['cols'],
-		       ($adding)?$row['value']:$value);
-	break;
-
-      case 'pageselector':
-	$contentops = $gCms->GetContentOperations();
+	// get the options
 	if( $value == '' ) $value = $row['value'];
-	$txt = $contentops->CreateHierarchyDropdown('',$value,$blockName,1,1);
-	break;
-
-      case 'dropdown':
-	{
-	  // get the options
-	  if( $value == '' ) $value = $row['value'];
-	  $tmp = explode("\n",$row['attribs']['options']);
-	  $opts = array();
-	  for( $i = 0; $i < count($tmp); $i++ )
-	    {
-	      if(empty($tmp[$i])) continue;
-	      $tmp2 = explode('|',trim($tmp[$i]),2);
-	      if( is_array($tmp2) && count($tmp2) == 2 )
-		{
-		  $opts[$tmp2[0]] = $tmp2[1];
-		}
-	      else
-		{
-		  $opts[$tmp2[0]] = $tmp2[0];
-		}
-	    }
-
-	  // build the field.
-	  $txt = $this->CreateInputDropdown('',$blockName,$opts,-1,$value);
+	$tmp = explode("\n",$row['attribs']['options']);
+	$opts = array();
+	for( $i = 0; $i < count($tmp); $i++ ) {
+	  if(empty($tmp[$i])) continue;
+	  $tmp2 = explode('|',trim($tmp[$i]),2);
+	  if( is_array($tmp2) && count($tmp2) == 2 ) {
+	    $opts[$tmp2[0]] = $tmp2[1];
+	  }
+	  else {
+	    $opts[$tmp2[0]] = $tmp2[0];
+	  }
 	}
-	break;
 
-      case 'checkbox':
-	{
-	  if( $value == '' && isset($row['options']['value']) ) $value = $row['options']['value'];
-	  $txt = $this->CreateInputHidden('',$blockName,isset($row['value'])?$row['value']:'').$this->CreateInputCheckbox('',$blockName,$row['attribs']['value'],$value);
-	}
-	break;
-
-      case 'radiobuttons':
-	{
-	  // get the options.
-	  if( $value == '' ) $value = $row['value'];
-	  $tmp = explode("\n",$row['attribs']['options']);
-	  $opts = array();
-	  for( $i = 0; $i < count($tmp); $i++ )
-	    {
-	      if(empty($tmp[$i])) continue;
-	      $tmp2 = explode('|',trim($tmp[$i]),2);
-	      if( is_array($tmp2) && count($tmp2) == 2 )
-		{
-		  $opts[$tmp2[0]] = $tmp2[1];
-		}
-	      else
-		{
-		  $opts[$tmp2[0]] = $tmp2[0];
-		}
-	    }
-
-	  // build the field.
-	  $txt = $this->CreateInputRadioGroup('',$blockName,$opts,$value,'','<br/>');
-	}
-	break;
-
-      case 'file_selector':
-	{
-	  // 1.  Get the directory contents
-	  $dir = cms_join_path($config['uploads_path'],$row['attribs']['dir']);
-	  $filetypes = $row['attribs']['filetypes'];
-	  if( $filetypes != '' )
-	    {
-	      $filetypes = explode(',',$filetypes);
-	      for( $i = 0; $i < count($filetypes); $i++ )
-		{
-		  $filetypes[$i] = '*.'.$filetypes[$i];
-		}
-	    }
-	  $excludes = $row['attribs']['excludeprefix'];
-	  if( $excludes != '' )
-	    {
-	      $excludes = explode(',',$excludes);
-	      for( $i = 0; $i < count($excludes); $i++ )
-		{
-		  $excludes[$i] = $excludes[$i].'*';
-		}
-	    }
-	  $fl = cge_dir::recursive_glob($dir,$filetypes,'FILES',$excludes,
-					$row['attribs']['recurse']);
-	  
-	  // 2.  Remove prefix
-	  for( $i = 0; $i < count($fl); $i++ )
-	    {
-	      $fl[$i] = str_replace($dir,'',$fl[$i]);
-	    }
-
-	  // 2.  Sort
-	  if( is_array($fl) && $row['attribs']['sortfiles'] )
-	    {
-	      sort($fl);
-	    }
-
-	  $opts = array();
-	  $url_prefix = $config['uploads_url'].'/'.$row['attribs']['dir'];
-	  for( $i = 0; $i < count($fl); $i++ )
-	    {
-	      $opts[$fl[$i]] = $url_prefix.$fl[$i];
-	    }
-	  $txt = $this->CreateInputDropdown('',$blockName,$opts,-1,$value);
-	}
-	break;
+	// build the field.
+	$txt = $this->CreateInputDropdown('',$blockName,$opts,-1,$value);
       }
+      break;
+
+    case 'checkbox':
+      {
+	if( $value == '' && isset($row['options']['value']) ) $value = $row['options']['value'];
+	$txt = $this->CreateInputHidden('',$blockName,isset($row['value'])?$row['value']:'').$this->CreateInputCheckbox('',$blockName,$row['attribs']['value'],$value);
+      }
+      break;
+
+    case 'radiobuttons':
+      {
+	// get the options.
+	if( $value == '' ) $value = $row['value'];
+	$tmp = explode("\n",$row['attribs']['options']);
+	$opts = array();
+	for( $i = 0; $i < count($tmp); $i++ ) {
+	  if(empty($tmp[$i])) continue;
+	  $tmp2 = explode('|',trim($tmp[$i]),2);
+	  if( is_array($tmp2) && count($tmp2) == 2 ) {
+	    $opts[$tmp2[0]] = $tmp2[1];
+	  }
+	  else {
+	    $opts[$tmp2[0]] = $tmp2[0];
+	  }
+	}
+
+	// build the field.
+	$txt = $this->CreateInputRadioGroup('',$blockName,$opts,$value,'','<br/>');
+      }
+      break;
+
+    case 'file_selector':
+      {
+	// 1.  Get the directory contents
+	$dir = cms_join_path($config['uploads_path'],$row['attribs']['dir']);
+	$filetypes = $row['attribs']['filetypes'];
+	if( $filetypes != '' ) {
+	  $filetypes = explode(',',$filetypes);
+	  for( $i = 0; $i < count($filetypes); $i++ ) {
+	    $filetypes[$i] = '*.'.$filetypes[$i];
+	  }
+	}
+	$excludes = $row['attribs']['excludeprefix'];
+	if( $excludes != '' ) {
+	  $excludes = explode(',',$excludes);
+	  for( $i = 0; $i < count($excludes); $i++ ) {
+	    $excludes[$i] = $excludes[$i].'*';
+	  }
+	}
+	$fl = cge_dir::recursive_glob($dir,$filetypes,'FILES',$excludes,
+				      $row['attribs']['recurse']);
+	  
+	// 2.  Remove prefix
+	for( $i = 0; $i < count($fl); $i++ ) {
+	  $fl[$i] = str_replace($dir,'',$fl[$i]);
+	}
+
+	// 2.  Sort
+	if( is_array($fl) && $row['attribs']['sortfiles'] ) {
+	  sort($fl);
+	}
+
+	$opts = array();
+	$url_prefix = $config['uploads_url'].'/'.$row['attribs']['dir'];
+	for( $i = 0; $i < count($fl); $i++ ) {
+	  $opts[$fl[$i]] = $url_prefix.$fl[$i];
+	}
+	$txt = $this->CreateInputDropdown('',$blockName,$opts,-1,$value);
+      }
+      break;
+    }
 
     return $txt;
   }
@@ -819,10 +611,7 @@ EOT;
 
   function GetContentBlockValue($blockName,$blockParams,$inputParams)
   {
-    if( isset($inputParams[$blockName]) )
-      {
-	return $inputParams[$blockName];
-      }
+    if( isset($inputParams[$blockName]) ) return $inputParams[$blockName];
   }
 
   function ValidateContentBlockValue($blockName,$value,$blockparams)
@@ -838,19 +627,17 @@ EOT;
     if( !$row ) return FALSE;
     $row['attribs'] = unserialize($row['attribs']);
 
-    if( isset($blockParams['required']) && $blockParams['required'] && empty($value) )
-      {
-	echo lang('nofieldgiven',array($blockName));
-      }
+    if( isset($blockParams['required']) && $blockParams['required'] && empty($value) ) {
+      echo lang('nofieldgiven',array($blockName));
+    }
   }
 
   function GetBulkContentOptions($userid)
   {
     $result = array();
-    if( $this->CheckPermission('Manage All Content') )
-      {
-	$result['copy'] = $this->Lang('copy');
-      }
+    if( $this->CheckPermission('Manage All Content') ) {
+      $result['copy'] = $this->Lang('copy');
+    }
 
     if( !count($result) ) return FALSE;
     return $result;
@@ -858,4 +645,4 @@ EOT;
 
 } // class
 
-?>
+?>
\ No newline at end of file
