@@ -73,29 +73,27 @@ $contentlist = explode(',',$params['contentlist']);
 foreach( $contentlist as $oneid )
 {
   // get the content object for this page.
-  $content =& $contentops->LoadContentFromId($oneid,true);
+  $content = $contentops->LoadContentFromId($oneid,true);
   $contents[$oneid] = $content;
-	$newdata[$oneid] = array();
+  $newdata[$oneid] = array();
 
-	// get a proposed new alias for this content block
-	{
-		$num = 2;
-		$newalias = $content->Alias().'_'.$num;
-		while ($contentops->CheckAliasError($newalias) !== FALSE)
-		{
-			$num++;
-			$newalias = $content->Alias().'_'.$num;
-		}
-		$newdata[$oneid]['new_alias'] = $newalias;
-	}
+  // get a proposed new alias for this content block
+  {
+    $num = 2;
+    $newalias = $content->Alias().'_'.$num;
+    while ($contentops->CheckAliasError($newalias) !== FALSE) {
+      $num++;
+      $newalias = $content->Alias().'_'.$num;
+    }
+    $newdata[$oneid]['new_alias'] = $newalias;
+  }
 
   // see if we have this template
-  if( !isset($templates[$content->TemplateId()]) )
-    {
-      // if not, load it too.
-      $template =& $templateops->LoadTemplateById($content->TemplateId());
-      $templates[$content->TemplateId()] = $template;
-    }
+  if( !isset($templates[$content->TemplateId()]) ) {
+    // if not, load it too.
+    $template = $templateops->LoadTemplateById($content->TemplateId());
+    $templates[$content->TemplateId()] = $template;
+  }
 }
 
 if (!function_exists('sort_by_hierarchy'))
@@ -114,23 +112,20 @@ if (!function_exists('sort_by_hierarchy'))
 
 uasort($contents, 'sort_by_hierarchy');
 
-if (!function_exists('parent_in_list'))
-{
-	function parent_in_list($list, $child)
-	{
-		if (!is_subclass_of($child, 'ContentBase'))
-			return false;
-
-		foreach ($list as $id => $obj)
-		{
-		  if ($obj->Id() == $child->ParentId())
-			{
-				return true;
-			}
-		}
+if (!function_exists('parent_in_list')) {
+  function parent_in_list($list, $child)
+  {
+    if (!is_subclass_of($child, 'ContentBase'))
+      return false;
+    
+    foreach ($list as $id => $obj) {
+      if ($obj->Id() == $child->ParentId()) {
+	return true;
+      }
+    }
 		
-		return false;
-	}
+    return false;
+  }
 }
 
 $parent_dropdowns = array();
@@ -139,44 +134,39 @@ $parent_dropdowns = array();
 // and if it's valid.
 foreach( $contents as $content_id => &$obj )
 {
-  if (parent_in_list($contents, $obj))
-	{
-		$result = $contentops->CreateHierarchyDropdown('', '', "{$id}new_parent_id[{$content_id}]", 1, 0, 0, true);
-		$result = str_replace('<option value="-1">none</option>', '<option value="0">Preserve Hierarchy</option><option value="-1">None</option>', $result);
-		$parent_dropdowns[$content_id] = $result;
-	}
-	else
-	{
-	  $result = $contentops->CreateHierarchyDropdown('', $obj->ParentId(), "{$id}new_parent_id[{$content_id}]", 1, 0, 0, true);
-		$result = str_replace('<option value="-1">none</option>', '<option value="-1">None</option>', $result);
-		$parent_dropdowns[$content_id] = $result;
-	}
+  if (parent_in_list($contents, $obj)) {
+    $result = $contentops->CreateHierarchyDropdown('', '', "{$id}new_parent_id[{$content_id}]", 1, 0, 0, true);
+    $result = str_replace('<option value="-1">none</option>', '<option value="0">Preserve Hierarchy</option><option value="-1">None</option>', $result);
+    $parent_dropdowns[$content_id] = $result;
+  }
+  else {
+    $result = $contentops->CreateHierarchyDropdown('', $obj->ParentId(), "{$id}new_parent_id[{$content_id}]", 1, 0, 0, true);
+    $result = str_replace('<option value="-1">none</option>', '<option value="-1">None</option>', $result);
+    $parent_dropdowns[$content_id] = $result;
+  }
 	
   if( !is_a($obj,'Content') ) continue;
 
   $blocks = $obj->get_content_blocks();
   if( !$blocks || !is_array($blocks) ) continue;
 
-  foreach( $blocks as $blockName => $blockInfo )
-    {
-      if( !isset($blockInfo['params']['promptoncopy']) || !$blockInfo['params']['promptoncopy'] ) continue;
+  foreach( $blocks as $blockName => $blockInfo ) {
+    if( !isset($blockInfo['params']['promptoncopy']) || !$blockInfo['params']['promptoncopy'] ) continue;
 
-      // found a promptoncopy block
-      if( !isset($addblocks[$content_id]) )
-	{
-	  $addblocks[$content_id] = array();
-	}
-
-      $value = $obj->GetPropertyValue($blockInfo['id']);
-      $blockInfo['inputname'] = "{$id}block_{$content_id}_{$blockName}";
-      $fld = $obj->display_content_block($blockName,$blockInfo,$value,true);
-      if( $fld )
-	{
-	  $blockInfo['fld_label'] = $fld[0];
-	  $blockInfo['fld_input'] = $fld[1];
-	  $addblocks[$content_id][$blockName] = $blockInfo;
-	}
+    // found a promptoncopy block
+    if( !isset($addblocks[$content_id]) ) {
+      $addblocks[$content_id] = array();
     }
+
+    $value = $obj->GetPropertyValue($blockInfo['id']);
+    $blockInfo['inputname'] = "{$id}block_{$content_id}_{$blockName}";
+    $fld = $obj->display_content_block($blockName,$blockInfo,$value,true);
+    if( $fld ) {
+      $blockInfo['fld_label'] = $fld[0];
+      $blockInfo['fld_input'] = $fld[1];
+      $addblocks[$content_id][$blockName] = $blockInfo;
+    }
+  }
 }
 
 $mapped_ids = array();
@@ -341,6 +331,7 @@ if( isset($params['submit']) )
 //
 // build our form
 //
+$smarty->assign('actionid',$id); // because the new parser calls smarty which can call modules and re-assign this.
 $smarty->assign('formstart',$this->CGCreateFormStart($id,'admin_copycontent','',$params));
 $smarty->assign('formend',$this->CreateFormEnd());
 $smarty->assign('prompt_parent',lang('parent'));
@@ -360,4 +351,4 @@ echo $this->ProcessTemplate('admin_copycontent.tpl');
 #
 # EOF
 #
-?>
\ No newline at end of file
+?>
