@@ -41,41 +41,35 @@ $modify_gcb = $this->CheckPermission('Modify Global Content Blocks');
 if( !$modify_templates && !$modify_udt && !$modify_gcb ) exit;
 
 // get a list of the module templates.
-if( $modify_templates )
-  {
-    $module_templates = array();
-    $modules = ModuleOperations::get_instance()->GetInstalledModules();
-    foreach( $modules as $module_name )
-      {
-	$templates = $this->ListTemplates($module_name);
-	if( count($templates) )
-	  {
-	    $module_templates[$module_name] = $templates;
-	  }
-      }
-
-    $tmp = array_keys($module_templates);
-    $module_list = array();
-    foreach( $tmp as $one )
-      {
-	$obj = $this->GetModuleInstance($one);
-	if( !$obj ) continue;
-	$module_list[$one] = $obj->GetFriendlyName();
-      }
-
-    $smarty->assign('module_list',$module_list);
-    $smarty->assign('num_modules',count($module_list));
+if( $modify_templates ) {
+  $module_templates = array();
+  $modules = ModuleOperations::get_instance()->GetInstalledModules();
+  foreach( $modules as $module_name ) {
+    $templates = $this->ListTemplates($module_name);
+    if( count($templates) ) {
+      $module_templates[$module_name] = $templates;
+    }
   }
 
-if( $modify_udt )
-  {
-    $smarty->assign('modify_udt',1);
-  }
-if( $modify_gcb )
-  {
-    $smarty->assign('modify_gcb',1);
+  $tmp = array_keys($module_templates);
+  $module_list = array();
+  foreach( $tmp as $one ) {
+    $obj = $this->GetModuleInstance($one);
+    if( !$obj ) continue;
+    $module_list[$one] = $obj->GetFriendlyName();
   }
 
+  $smarty->assign('module_list',$module_list);
+  $smarty->assign('num_modules',count($module_list));
+ }
+
+if( $modify_udt ) {
+  $smarty->assign('modify_udt',1);
+ }
+if( $modify_gcb ) {
+  $smarty->assign('modify_gcb',1);
+ }
+
 $smarty->assign('formstart',$this->CGCreateFormStart($id,'admin_export_code'));
 $smarty->assign('formend',$this->CreateFormEnd());
 $smarty->assign('ajax_url',$this->CreateUrl($id,'admin_ajax_gettemplates',$returnid));
